@@ -72,9 +72,10 @@ import Distribution.Package
        (PackageName(..), PackageIdentifier(..))
 import Distribution.ModuleName (components, ModuleName)
 import Data.ByteString.Char8 (ByteString)
-import Distribution.Text (Text(..), simpleParse, display)
+import Distribution.Text (simpleParse, display)
 import qualified Data.ByteString.Char8 as  BS (unpack, empty)
-import qualified Data.Map as Map (lookup,keysSet,splitLookup, insertWith,empty,elems,union)
+import qualified Data.Map as Map (lookup,keysSet,splitLookup, insertWith,empty,elems,union,toList)
+import qualified Data.Set as Set (toList)
 import Text.PrettyPrint as PP
 import Text.PrinterParser
 import Data.Char (isAlpha)
@@ -89,7 +90,7 @@ import qualified Distribution.InstalledPackageInfo as IPI
 --
 
 leksahVersion, configDirName :: String
-leksahVersion = "0.10"
+leksahVersion = "0.12"
 configDirName = ".leksah-" ++ leksahVersion
 
 metadataVersion :: Integer
@@ -475,6 +476,14 @@ isOperator _         =  False
 -- ---------------------------------------------------------------------
 -- NFData instances for forcing evaluation
 --
+#if MIN_VERSION_deepseq(1,2,0) && !MIN_VERSION_containers(0,4,2)
+instance (NFData k, NFData a) => NFData (Map k a) where
+    rnf = rnf . Map.toList
+
+instance NFData a => NFData (Set a) where
+    rnf = rnf . Set.toList
+#endif
+
 instance NFData Location where
 
     rnf pd =  rnf (locationSLine pd)
@@ -535,7 +544,9 @@ instance NFData DescrType where  rnf a = seq a ()
 
 instance NFData BS.ByteString where  rnf b = seq b ()
 
+#if !MIN_VERSION_deepseq(1,3,0)
 instance NFData Version where  rnf v = seq v ()
+#endif
 
 instance NFData PackModule where
     rnf pd =  rnf (pack pd)
