@@ -31,6 +31,7 @@ import Data.Typeable (Typeable(..))
 import Distribution.Package (PackageName(..),PackageIdentifier(..))
 import Data.Version (Version(..))
 import Distribution.ModuleName (ModuleName)
+import MyMissing (forceJust)
 
 import IDE.Core.CTypes
 
@@ -233,7 +234,7 @@ instance BinaryShared Location where
 
 instance BinaryShared ModuleName where
     put    =  put . display
-    get    =  liftM (fromJust . simpleParse) get
+    get    =  liftM (flip forceJust "BinaryShared>>get(ModuleName)" . simpleParse) get
 
 instance BinaryShared PackageName where
     put (PackageName pn) =  put pn
