@@ -64,7 +64,7 @@ import IDE.Utils.GHCUtils (inGhcIO)
 import qualified Control.Exception as NewException (SomeException, catch)
 import IDE.Utils.Tool
 import Control.Monad (unless)
-import IDE.Utils.FileUtils (figureOutGhcOpts, figureOutHaddockOpts,myCanonicalizePath)
+import IDE.Utils.FileUtils (figureOutGhcOpts, myCanonicalizePath)
 import Distribution.Package(PackageIdentifier)
 import GHC hiding(Id,Failed,Succeeded,ModuleName)
 import System.Log.Logger (warningM, debugM)
@@ -104,11 +104,7 @@ findSourceForPackage :: Prefs -> PackageConfig -> IO (Either String FilePath)
 findSourceForPackage prefs packageConfig = do
     sourceMap <- liftIO $ getSourcesMap prefs
     case sourceForPackage (getThisPackage packageConfig) sourceMap of
-        Just fpSource -> do
-            let dirPath      = dropFileName fpSource
-            setCurrentDirectory dirPath
-            runTool' "cabal" (["configure","--user"]) Nothing
-            return (Right fpSource)
+        Just fpSource -> return (Right fpSource)
         Nothing -> do
             unpackDir <- getUnpackDirectory prefs
             case unpackDir of
@@ -121,13 +117,7 @@ findSourceForPackage prefs packageConfig = do
                     success <- doesDirectoryExist (fpUnpack </> packageName)
                     if not success
                         then return (Left "Failed to download and unpack source")
-                        else do
-                            setCurrentDirectory (fpUnpack </> packageName)
-                            NewException.catch (runTool' "cabal" (["configure","--user"]) Nothing >> return ())
-                                                    (\ (_e :: NewException.SomeException) -> do
-                                                        debugM "leksah-server" "Can't configure"
-                                                        return ())
-                            return (Right (fpUnpack </> packageName </>  takeWhile (/= '-') packageName <.> "cabal"))
+                        else return (Right (fpUnpack </> packageName </>  takeWhile (/= '-') packageName <.> "cabal"))
     where
         packageName = packageIdentifierToString (getThisPackage packageConfig)
 
@@ -185,6 +175,9 @@ interfaceToModuleDescr _dirPath pid interface =
                         (ifaceInstances interface) [] --(ifaceLocals interface)
         imports    = Map.empty --TODO
 
+#if MIN_VERSION_ghc(7,4,1)
+type DeclInfo = [LHsDecl Name]
+#endif
 #if MIN_VERSION_ghc(6,12,1)
 extractDescrs :: PackModule -> Map Name DeclInfo -> [ExportItem Name] -> [Instance] -> [Name] -> [Descr]
 extractDescrs pm _ifaceDeclMap ifaceExportItems' ifaceInstances' _ifaceLocals =
@@ -213,7 +206,11 @@ extractDescrs pm _ifaceDeclMap ifaceExportItems' ifaceInstances' _ifaceLocals =
 transformToDescrs :: PackModule -> [(LHsDecl Name, Maybe NDoc, [(Name, Maybe NDoc)])] -> [Descr]
 transformToDescrs pm = concatMap transformToDescr
     where
+#if MIN_VERSION_ghc(7,2,0)
+    transformToDescr ((L loc (SigD (TypeSig [name] typ))), mbComment,_subCommentList) =
+#else
     transformToDescr ((L loc (SigD (TypeSig name typ))), mbComment,_subCommentList) =
+#endif
         [Real $ RealDescr {
         dscName'        =   getOccString (unLoc name)
     ,   dscMbTypeStr'   =   Just (BS.pack (showSDocUnqual $ppr typ))
@@ -271,7 +268,7 @@ transformToDescrs pm = concatMap transformToDescr
         derivings Nothing = []
         derivings (Just _l) = []
 
-    transformToDescr ((L loc (TyClD cl@(ClassDecl _ tcdLName' _ _ tcdSigs' _ _ docs))), mbComment,_subCommentList) =
+    transformToDescr ((L loc (TyClD cl@(ClassDecl{tcdLName=tcdLName', tcdSigs=tcdSigs', tcdDocs=docs}))), mbComment,_subCommentList) =
         [Real $ RealDescr {
         dscName'        =   getOccString (unLoc tcdLName')
     ,   dscMbTypeStr'   =   Just (BS.pack (showSDocUnqual $ppr cl{tcdMeths = emptyLHsBinds}))
@@ -303,7 +300,11 @@ extractMethods sigs docs =
     in mapMaybe extractMethod pairs
 
 extractMethod :: (LHsDecl Name, Maybe NDoc) -> Maybe SimpleDescr
+#if MIN_VERSION_ghc(7,2,0)
+extractMethod ((L loc (SigD ts@(TypeSig [name] _typ))), mbDoc) =
+#else
 extractMethod ((L loc (SigD ts@(TypeSig name _typ))), mbDoc) =
+#endif
     Just $ SimpleDescr
         (getOccString (unLoc name))
         (Just (BS.pack (showSDocUnqual $ ppr ts)))
@@ -371,7 +372,7 @@ instance Outputable alpha => Show (PPDoc alpha)  where
     showsPrec _ (PPDoc (DocString str))          =   showString str
     showsPrec _ (PPDoc (DocParagraph d))         =   shows (PPDoc d) . showChar '\n'
     showsPrec _ (PPDoc (DocIdentifier l))        =   foldr (\i _f -> showChar '\'' .
-                                                     ((showString . showSDoc .  ppr) i) . showChar '\'') id l
+                                                     ((showString . showSDoc .  ppr) i) . showChar '\'') id [l]
     showsPrec _ (PPDoc (DocModule str))          =   showChar '"' . showString str . showChar '"'
     showsPrec _ (PPDoc (DocEmphasis doc))        =   showChar '/' . shows (PPDoc doc)  . showChar '/'
     showsPrec _ (PPDoc (DocMonospaced doc))      =   showChar '@' . shows (PPDoc doc) . showChar '@'
