@@ -17,6 +17,7 @@ module IDE.Utils.FileUtils (
     allModules
 ,   allHiFiles
 ,   allHaskellSourceFiles
+,   isEmptyDirectory
 ,   cabalFileName
 ,   allCabalFiles
 ,   getConfigFilePathForLoad
@@ -44,7 +45,7 @@ module IDE.Utils.FileUtils (
 
 import System.FilePath
        (splitFileName, dropExtension, takeExtension,
-        combine, addExtension, (</>), normalise, splitPath)
+        combine, addExtension, (</>), normalise, splitPath, takeFileName)
 import Distribution.ModuleName (toFilePath, ModuleName)
 import Control.Monad (foldM, filterM)
 import Data.Maybe (catMaybes)
@@ -69,15 +70,7 @@ import Data.Set (Set)
 import Data.List
     (isPrefixOf, isSuffixOf, stripPrefix)
 import qualified Data.Set as  Set (empty, fromList)
-import Control.Monad.Trans (MonadIO(..))
 import Distribution.Package (PackageIdentifier)
-#ifdef MIN_VERSION_process_leksah
-import IDE.System.Process
-    (waitForProcess, runCommand)
-#else
-import System.Process
-    (waitForProcess, runCommand)
-#endif
 import Data.Char (ord)
 import Distribution.Text (simpleParse)
 
@@ -86,6 +79,7 @@ import IDE.Core.CTypes(configDirName)
 import qualified Distribution.Text as  T (simpleParse)
 import System.Log.Logger(errorM,warningM,debugM)
 import IDE.Utils.Tool
+import Control.Monad.IO.Class (MonadIO(..), MonadIO)
 
 haskellSrcExts :: [String]
 haskellSrcExts = ["hs","lhs","chs","hs.pp","lhs.pp","chs.pp","hsc"]
@@ -312,6 +306,16 @@ findKnownPackages filePath = catch (do
     return (Set.fromList nameList))
         $ \ _ -> return (Set.empty)
 
+isEmptyDirectory :: FilePath -> IO Bool
+isEmptyDirectory filePath = catch (do
+    exists <- doesDirectoryExist filePath
+    if exists
+        then do
+            filesAndDirs <- getDirectoryContents filePath
+            return . null $ filter (not . ("." `isPrefixOf`) . takeFileName) filesAndDirs
+        else return False)
+        (\_ -> return False)
+
 cabalFileName :: FilePath -> IO (Maybe FilePath)
 cabalFileName filePath = catch (do
     exists <- doesDirectoryExist filePath
